#
# spec file for package cli11
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upstream_name CLI11

Name:           cli11
Version:        2.3.2
Release:        1.2
Summary:        Command line parser for C++11
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

URL:            https://github.com/CLIUtils/CLI11
Source:         %{upstream_name}-%{version}.tar.gz
BuildRequires:  Catch2-2-devel
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  python3-devel
BuildArch:      noarch

%description
CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set.

%package devel
Summary:        Development files for CLI11

%description devel
CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set. It is header only, and has a number of design
limits by choice:

 * No completion of partial options (like --ve for --version,
   if it were unambiguous)
 * No wide strings/Unicode

%package      doc
Summary:        Documentation for CLI11
Group:          Documentation/Other

%description  doc
This package contains documentation for CLI11

CLI11 is a command line parser for C++11 and beyond that provides a
rich feature set. It is header only, and has a number of design
limits by choice:

 * No completion of partial options (like --ve for --version,
   if it were unambiguous)
 * No wide strings/Unicode

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
%cmake \
%if 0%{?sle_version} <= 150300 && 0%{?suse_version} <= 1500
  -DCLI11_BUILD_TESTS:BOOL=FALSE \
%else
  -DCLI11_BUILD_TESTS:BOOL=TRUE \
%endif
  -DCLI11_BUILD_DOCS:BOOL=TRUE \
  -DCLI11_BUILD_EXAMPLES:BOOL=FALSE
%cmake_build all docs

%install
%cmake_install

%if 0%{?sle_version} <= 150300 && 0%{?suse_version} <= 1500
%else

%check
%ctest
%endif

%files devel
%license LICENSE
%doc CHANGELOG.md
%dir %{_includedir}/CLI
%dir %{_includedir}/CLI/impl
%{_includedir}/CLI/*.hpp
%{_includedir}/CLI/impl/*.hpp
%dir %{_datadir}/cmake/CLI11/
%{_datadir}/cmake/CLI11/*.cmake
%{_datadir}/pkgconfig/CLI11.pc

%files doc
%doc build/docs/html/

%changelog
* Sat Jan  7 2023 Haochuan Chen <haochuan.chen@univ-lorraine.fr>
- Update to version 2.3.2:
  * Bugfix: Consistently use ADL for lexical_cast, making it easier to extend for custom template types #820
  * Bugfix: Tweak the parsing of files for flags with disable_flag_override #800]
  * Bugfix: Handle out of bounds long long #807
  * Bugfix: Spacing of make_description min option output #808
  * Bugfix: Print last parsed subcommand's help message #822
  * Bugfix: Avoid floating point warning in GCC 12 #803
  * Bugfix: Fix a few gcc warnings #813
  * Backend: Max CMake tested 3.22 -> 3.24 #823
- Update to version 2.3.1:
  * Bugfix: App::get_option_group implementation missing #793
  * Bugfix: Fix spacing when setting an empty footer #796
  * Bugfix: Address Klocwork static analysis checking issues #785
* Mon Oct 24 2022 Haochuan Chen <haochuan.chen@univ-lorraine.fr>
- Disable tests for %%{?sle_version} <= 150300 due to possible issues of old
  cmake versions
* Mon Oct 24 2022 Haochuan Chen <haochuan.chen@univ-lorraine.fr>
- Although the pre-compiled mode has been introduced upstream, it is still not
  able to build shared libs, so CLI11_PRECOMPILED is default to be disabled.
  The package is then still header-only, and the build architecture is changed
  to noarch.
- Tests are enabled during building.
- Upstream changes: update to version 2.3.0
  * Add CLI11_PRECOMPILED as an option. #762
  * Bugfix: Include <functional> in FormatterFwd #727
  * Bugfix: Add missing Macros.hpp to Error.hpp #755
  * Bugfix: Fix subcommand callback trigger #733
  * Bugfix: Variable rename to avoid warning #734
  * Bugfix: split_program_name single file name error #740
  * Bugfix: Better support for min/max overrides on MSVC #741
  * Bugfix: Support MSVC 2022 #748
  * Bugfix: Support negated flag in config file #775
  * Bugfix: Better errors for some confusing config file situations #781
  * Backend: Restore coverage testing (lost with Travis CI) #747
* Wed Apr 13 2022 Haochuan Chen <yjcoshc@mail.nankai.edu.cn>
- Update to version 2.2.0
  * Add `MultiOptionPolicy::Sum`  and refactor the `add_flag` to fix a bug when using `std::optional<bool>` as type.
  * Add support for an empty vector result in TOML and as a default string.
  * Add `.validate_optional_arguments()` to support discriminating positional arguments from vector option arguments.
  * Add `CLI::FileOnDefaultPath` to check for files on a specified default path.
  * Change default value display in help messages from `=XXXX` to `[XXXXX]` to make it clearer.
  * Modify the Range Validator to support additional types and clean up the error output.
  * Bugfix: The trigger on parse modifier did not work on positional argument.s
  * Bugfix: The single header file generation was missing custom namespace generation.
  * Bugfix: Clean up File Error handling in the argument processing.
  * Bugfix: Fix a stack overflow error if nameless commands had fallthrough.
  * Bugfix: A subcommand callback could be executed multiple times if it was a member of an option group.
  * Bugfix: Fix an issue with vectors of multi argument types where partial argument sets did not result in an error.
  * Bugfix: Fix an issue with type the template matching on C++20 and add some CI builds for C++20.
  * Bugfix: Fix typo in C++20 detection on MSVC.
  * Bugfix: An issue where the detection of RTTI being disabled on certain MSVC platforms did not disable the use of dynamic cast calls.
  * Bugfix: Resolve strict-overflow warning on some GCC compilers.
  * Backend: Add additional tests concerning the use of aliases for option groups in config files.
  * Build: Add support for testing in meson and cleanup symbolic link generation.
  * Build: Support building in WebAssembly.
* Mon Nov 22 2021 Haochuan Chen <yjcoshc@mail.nankai.edu.cn>
- Build doc package
- Include pkgconfig file
- Disable the build of examples
- Change the directory of cmake files to %%{_datadir}/cmake
- Use the upstream name for source and building, and keep the
  package name lowercase
- Update to version 2.1.2
  * Use main for the main branch of the repository
  * Bugfix(cmake): Enforce at least C++11 when using CMake target
  * Build: Don't run doxygen and CTest includes if a submodule
  * Build: Avoid a warning on CMake 3.22
  * Build: Support compiling the tests with an external copy of Catch2
* Thu Oct  8 2020 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from description and supply actual limits.
* Fri Sep 25 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Initial import of CLI11 1.9.1
